@@ -6,8 +6,7 @@ use Moo;
 use TheParameterizedRole;
 
 TheParameterizedRole->apply(
-    [
-        { attribute => 'foo', method => 'xxx' },
+    [   { attribute => 'foo', method => 'xxx' },
         { attribute => 'bar', method => 'yyy' }
     ]
 );
